==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Rulers and Scrollbars</source>
        <translation>Réguas e barras de rolagem</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Exiba réguas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Mostrar barras de rolagem</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Mostrar mira</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Exiba mira grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grade</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Grade escalonada automaticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Grade linhas de sólidas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espaçamento mínimo da grade (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Grade escalonada meta automaticamente</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Close automático</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Margin (px):</source>
        <translation>Margem (px):</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Color Adjustment</source>
        <translation>Ajuste de cor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corrigir as cores preto e branco</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Limiar para a luminosidade da cor:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Tipos de linha</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Escala padrão para a espessura de linha 0,00mm:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Usar automaticamente tipos de linha baseado em tela, tendo em vista modelo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch linetypes</source>
        <translation>Ajustar automaticamente os tipos de linha</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Performance</source>
        <translation>Desempenho</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Number of preview entities:</source>
        <translation>Número de entidades de prévia:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Mostrar limite para o texto (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Arcos Resultados por linhas abaixo deste ângulo (graus):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar limite para o texto:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Selection</source>
        <translation>Selecção</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Seleção persistente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_pt.ts--
Ver gráficos</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réguas e barras de rolagem</translation>
    </message>
    <message>
        <source>Show rulers</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Exiba réguas</translatorcomment>
        <translation type="obsolete">Exiba réguas</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar barras de rolagem</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostrar barras de rolagem</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
Entidade &amp;destacada sob o cursor do mouse
Entidade destacada sob o cursor do mouse
 sob cursor
Coordenadas do cursor</translatorcomment>
        <translation type="obsolete">Cursor</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar mira</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Exiba mira grande
Exiba mira grande</translatorcomment>
        <translation type="obsolete">Exiba mira grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation type="obsolete">Grade</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Grade escalonada automaticamente</translatorcomment>
        <translation type="obsolete">Grade escalonada automaticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Linhas de grade sólidas</translatorcomment>
        <translation type="obsolete">Grade linhas de sólidas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Espaçamento Mínimo da Grade (px):</translatorcomment>
        <translation type="obsolete">Espaçamento mínimo da grade (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Close automático</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajuste de cor</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corrigir as cores preto e branco</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Limiar para a luminosidade da cor:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Desempenho</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar limite para o texto:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Close Automático
Close Automático
Close automático</translatorcomment>
        <translation type="obsolete">Ampliação</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margem (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation type="obsolete">Pré-visualizar</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Número de entidades de prévia:</translatorcomment>
        <translation type="obsolete">Número de entidades de prévia:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crie um novo carimbo a partir de entidades existentes
Desselecione todas as Entidades</translatorcomment>
        <translation type="obsolete">Entidades</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corrigir as cores preto e branco</translation>
    </message>
    <message>
        <source>Selection</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Continue a ação (a seleção está completa)
&amp;Ponteiro de Seleção</translatorcomment>
        <translation type="obsolete">Selecção</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Seleções &amp;Persistentes
Seleções Persistentes</translatorcomment>
        <translation type="obsolete">Seleção persistente</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Réguas e Barras de Rolagem</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Exiba réguas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Exiba barras de rolagem</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Exiba miras</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Exiba miras grandes</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grade</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Grade escalonada automaticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Grade linhas de sólidas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espaçamento mínimo da grade (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Grade escalonada meta automaticamente</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Exiba o eixo de origem grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom Automático</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Margem (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Zoom automático após o carregamento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Ajuste de Cor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corrigir cores preto-no-preto e branco-no-branco</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Limites para a luminosidade da cor:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Tipos de Linha</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Comute automaticamente para tipos de linha baseados na tela, na visão de modelagem</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Escalone os padrões de tipos de linha, tendo como base a espessura da linha</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Escala padrão para a espessura de linha de 0,00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Visualização e Desempenho</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Mostre entidades com mais de N traços como contínuas:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Passo mínimo de ângulo para renderização de arcos (graus):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Use resolução total para a exposição Retina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Suavização ativada como padrão</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Número máximo de pontos de referência exibidos:</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Tempo de espera para renderização de hachura:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Suavização ativada como padrão</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Use automaticamente tipos de linha baseados em tela, na visão de modelagem</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Ajustar automaticamente os tipos de linha</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Desempenho</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Número de entidades para a prévia:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Limite da altura do texto de visualização (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Exiba arcos como linhas, abaixo deste ângulo (graus):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar limite para o texto:</translation>
    </message>
    <message>
        <location line="+331"/>
        <source>Selection</source>
        <translation>Seleção</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Seleção Persistente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_pt.ts--
Ver gráficos</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réguas e barras de rolagem</translation>
    </message>
    <message>
        <source>Show rulers</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Exiba réguas</translatorcomment>
        <translation type="obsolete">Exiba réguas</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar barras de rolagem</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostrar barras de rolagem</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
Entidade &amp;destacada sob o cursor do mouse
Entidade destacada sob o cursor do mouse
 sob cursor
Coordenadas do cursor</translatorcomment>
        <translation type="obsolete">Cursor</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar mira</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Exiba mira grande
Exiba mira grande</translatorcomment>
        <translation type="obsolete">Exiba mira grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation type="obsolete">Grade</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Grade escalonada automaticamente</translatorcomment>
        <translation type="obsolete">Grade escalonada automaticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Linhas de grade sólidas</translatorcomment>
        <translation type="obsolete">Grade linhas de sólidas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Espaçamento Mínimo da Grade (px):</translatorcomment>
        <translation type="obsolete">Espaçamento mínimo da grade (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Close automático</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajuste de cor</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corrigir as cores preto e branco</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Limiar para a luminosidade da cor:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Desempenho</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar limite para o texto:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Close Automático
Close Automático
Close automático</translatorcomment>
        <translation type="obsolete">Ampliação</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margem (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation type="obsolete">Pré-visualizar</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Número de entidades de prévia:</translatorcomment>
        <translation type="obsolete">Número de entidades de prévia:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crie um novo carimbo a partir de entidades existentes
Desselecione todas as Entidades</translatorcomment>
        <translation type="obsolete">Entidades</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corrigir as cores preto e branco</translation>
    </message>
    <message>
        <source>Selection</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Continue a ação (a seleção está completa)
&amp;Ponteiro de Seleção</translatorcomment>
        <translation type="obsolete">Selecção</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Seleções &amp;Persistentes
Seleções Persistentes</translatorcomment>
        <translation type="obsolete">Seleção persistente</translation>
    </message>
</context>
</TS>
